```
Usage: vcd pvdc migrate-vms [OPTIONS] <pvdc-name> <source-rp> <vm-name>

Options:
  -t, --target-rp [target-rp]  target resource pool name
  -h, --help                   Show this message and exit.

```
